@@ -26,17 +26,22 @@ namespace Model
     ap_southeast_1,
     ap_southeast_2,
     ap_southeast_3,
+    ap_southeast_4,
+    ap_southeast_5,
     ca_central_1,
     cn_north_1,
     cn_northwest_1,
     EU,
     eu_central_1,
+    eu_central_2,
     eu_north_1,
     eu_south_1,
     eu_south_2,
     eu_west_1,
     eu_west_2,
     eu_west_3,
+    il_central_1,
+    me_central_1,
     me_south_1,
     sa_east_1,
     us_east_2,
